@@ -89,7 +89,6 @@ class Image(object):
                 if ":" in image:
                     image = image.split(":", 1)[0]
                 if image in container_names:
-                    name = container_names[image]
                     candidates.append(container_names[image])
 
         if self.volumes_from:
@@ -210,7 +209,7 @@ class Image(object):
             ports = self.figure_out_ports(extra_ports)
 
             tty = not detach and self.interactive
-            links = [link.split(":") for link in self.link]
+            links = [(link.split(":") if ":" in link else (link, link)) for link in self.link]
             volumes = self.volumes
             if extra_volumes:
                 if volumes is None:
@@ -238,6 +237,8 @@ class Image(object):
             , detach=False, command=None, tty=True, volumes=None, volumes_from=None, links=None, delete_on_exit=False, env=None, ports=None, dependency=False, no_intervention=False
             ):
         """Run a single container"""
+        if not detach and dependency:
+            tty = True
         log.info("Creating container from %s\timage=%s\tcontainer_name=%s\ttty=%s", image_name, name, container_name, tty)
 
         binds = {}
@@ -529,12 +530,21 @@ class Image(object):
     @contextmanager
     def make_context(self):
         """Context manager for creating the context of the image"""
+        class Nope(object): pass
         host_context = not self.heira_formatted("no_host_context", default=False)
         context_exclude = self.heira_formatted("context_exclude", default=None)
-        respect_gitignore = self.heira_formatted("respect_gitignore", default=False)
-        use_git_timestamps = self.heira_formatted("use_git_timestamps", default=True)
+        respect_gitignore = self.heira_formatted("respect_gitignore", default=Nope)
+        use_git_timestamps = self.heira_formatted("use_git_timestamps", default=Nope)
+
+        use_git = False
+        if respect_gitignore is not Nope and respect_gitignore:
+            use_git = True
+        if use_git_timestamps is not Nope and use_git_timestamps:
+            use_git = True
+
+        respect_gitignore = use_git if respect_gitignore is Nope else False
+        use_git_timestamps = use_git if use_git_timestamps is Nope else False
 
-        use_git = respect_gitignore or use_git_timestamps
         git_files = set()
         changed_files = set()
 
